@@ -1,11 +1,13 @@
 """CLI tests for `python_build_utils.collect_pyd_modules`.
 
 Covers scenarios like:
-- Default module collection
+- Default module collection (.pyd on Windows-like layout)
 - Regex filtering
 - Collection of `.py` modules
+- Collection of `.so` modules (Unix-like layout)
 - Writing to output file
 - Handling of invalid or missing site-packages path
+- Normalization of '__init__' with ABI suffixes
 """
 
 import logging
@@ -17,21 +19,19 @@ from click.testing import CliRunner
 from python_build_utils.collect_pyd_modules import collect_pyd_modules
 
 
+# Ensure the module logger is chatty enough for caplog in INFO tests
 logger = logging.getLogger("python_build_utils.collect_pyd_modules")
 logger.setLevel(logging.INFO)
 
 
+# -------------------------------------------------------------------------------------------------
+# Fixtures
+# -------------------------------------------------------------------------------------------------
+
+
 @pytest.fixture
 def mock_venv_structure(tmp_path: Path) -> Path:
-    """Create a mock venv directory structure with site-packages and files.
-
-    Args:
-        tmp_path: Temporary directory for the mock venv.
-
-    Returns:
-        Path: Root path of the mock venv.
-
-    """
+    """Windows-like venv: <venv>/Lib/site-packages with .pyd and .py files."""
     site_packages = tmp_path / "Lib" / "site-packages"
     site_packages.mkdir(parents=True)
 
@@ -45,6 +45,27 @@ def mock_venv_structure(tmp_path: Path) -> Path:
     return tmp_path
 
 
+@pytest.fixture
+def mock_venv_structure_unix(tmp_path: Path) -> Path:
+    """Unix-like venv: <venv>/lib/python3.12/site-packages with .so and .py files."""
+    site_packages = tmp_path / "lib" / "python3.12" / "site-packages"
+    site_packages.mkdir(parents=True)
+
+    (site_packages / "upkg").mkdir()
+    (site_packages / "upkg" / "umod1.cpython-312-x86_64-linux-gnu.so").touch()
+    (site_packages / "upkg" / "subu").mkdir()
+    (site_packages / "upkg" / "subu" / "umod2.cpython-312-x86_64-linux-gnu.so").touch()
+    (site_packages / "upkg" / "__init__.cpython-312-x86_64-linux-gnu.so").touch()
+    (site_packages / "upkg" / "ualt.py").touch()
+
+    return tmp_path
+
+
+# -------------------------------------------------------------------------------------------------
+# Tests (Windows-like / .pyd)
+# -------------------------------------------------------------------------------------------------
+
+
 def test_collect_pyd_modules_default(mock_venv_structure: Path) -> None:
     """Collect .pyd modules from the mock environment using default options."""
     runner = CliRunner()
@@ -52,6 +73,7 @@ def test_collect_pyd_modules_default(mock_venv_structure: Path) -> None:
 
     assert result.exit_code == 0
     output = result.output.strip().splitlines()
+    # Package __init__ maps to just 'pkg'
     assert "pkg" in output
     assert "pkg.mod1" in output
     assert "pkg.subpkg.mod2" in output
@@ -72,7 +94,7 @@ def test_collect_pyd_modules_with_regex(mock_venv_structure: Path) -> None:
 
 
 def test_collect_pyd_modules_py_mode(mock_venv_structure: Path) -> None:
-    """Collect .py modules instead of .pyd when --collect-py is used."""
+    """Collect .py modules instead of compiled ones when --collect-py is used."""
     runner = CliRunner()
     result = runner.invoke(
         collect_pyd_modules,
@@ -82,7 +104,7 @@ def test_collect_pyd_modules_py_mode(mock_venv_structure: Path) -> None:
     assert result.exit_code == 0
     output = result.output
     assert "pkg.altmod" in output
-    assert "mod1" not in output
+    assert "mod1" not in output  # ensure compiled names are not present
 
 
 def test_collect_pyd_modules_output_file(mock_venv_structure: Path, tmp_path: Path) -> None:
@@ -114,6 +136,7 @@ def test_collect_pyd_modules_site_packages_not_found(
         result = runner.invoke(collect_pyd_modules, [])
 
     assert result.exit_code == 0
+    # Should log an error about site-packages not found
     assert any("Could not locate site-packages" in r.message for r in caplog.records)
 
 
@@ -125,21 +148,24 @@ def test_collect_pyd_modules_invalid_path(
     invalid_path = tmp_path / "does_not_exist"
     runner = CliRunner()
 
-    with caplog.at_level("ERROR"):
+    with caplog.at_level(logging.ERROR):
         result = runner.invoke(collect_pyd_modules, ["--venv-path", str(invalid_path)])
 
     assert result.exit_code == 0
     assert any("does not exist" in record.message for record in caplog.records)
 
 
-def test_collect_pyd_modules_no_matches(mock_venv_structure: Path, caplog: pytest.LogCaptureFixture) -> None:
+def test_collect_pyd_modules_no_matches(
+    mock_venv_structure: Path,
+    caplog: pytest.LogCaptureFixture,
+) -> None:
     """Log and return None when no modules match regex or extension."""
     runner = CliRunner()
-
-    result = runner.invoke(
-        collect_pyd_modules,
-        ["--venv-path", str(mock_venv_structure), "--collect-py", "--regex", "doesnotmatch"],
-    )
+    with caplog.at_level(logging.INFO):
+        result = runner.invoke(
+            collect_pyd_modules,
+            ["--venv-path", str(mock_venv_structure), "--collect-py", "--regex", "doesnotmatch"],
+        )
 
     assert result.exit_code == 0
 
@@ -153,7 +179,7 @@ def test_collect_pyd_modules_no_matches(mock_venv_structure: Path, caplog: pytes
 
 
 def test_extract_submodule_name_with_suffix_and_init(tmp_path: Path) -> None:
-    """Test that '__init__.cp311-win_amd64.pyd' is correctly normalized to package name."""
+    """'__init__.cp311-win_amd64.pyd' is normalized to package name."""
     site_packages = tmp_path / "site-packages"
     package_dir = site_packages / "my_package"
     package_dir.mkdir(parents=True)
@@ -164,7 +190,6 @@ def test_extract_submodule_name_with_suffix_and_init(tmp_path: Path) -> None:
     from python_build_utils.collect_pyd_modules import _extract_submodule_name
 
     result = _extract_submodule_name(init_file, site_packages)
-
     assert result == "my_package"
 
 
@@ -176,10 +201,6 @@ def test_collect_pyd_modules_output_written_via_cli(tmp_path: Path) -> None:
 
     output_file = tmp_path / "mods.txt"
 
-    from click.testing import CliRunner
-
-    from python_build_utils.collect_pyd_modules import collect_pyd_modules
-
     runner = CliRunner()
     result = runner.invoke(
         collect_pyd_modules,
@@ -191,3 +212,28 @@ def test_collect_pyd_modules_output_written_via_cli(tmp_path: Path) -> None:
     contents = output_file.read_text(encoding="utf-8")
     assert "pkg.mod" in contents
     assert f"Module list written to {output_file}" in result.output
+
+
+# -------------------------------------------------------------------------------------------------
+# Tests (Unix-like / .so)
+# -------------------------------------------------------------------------------------------------
+
+
+def test_collect_so_modules_unix_layout(mock_venv_structure_unix: Path) -> None:
+    """Collect .so modules from a Unix-like venv using --ext=so."""
+    runner = CliRunner()
+    result = runner.invoke(
+        collect_pyd_modules,
+        ["--venv-path", str(mock_venv_structure_unix), "--ext=so"],
+    )
+
+    assert result.exit_code == 0
+    output = result.output.strip().splitlines()
+
+    # __init__ yields just the package name
+    assert "upkg" in output
+    # regular modules
+    assert "upkg.umod1" in output
+    assert "upkg.subu.umod2" in output
+    # .py should not appear when ext=so
+    assert "upkg.ualt" not in output
